==> haskell-tasty-smallcheck-0.8.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-LBf05hPzGNpHeKs4oIkgUK
key: tasty-smallcheck-0.8.1-LBf05hPzGNpHeKs4oIkgUK
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.SmallCheck
abi: 270a3bdc540b1796ac64bc893125b481
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-LBf05hPzGNpHeKs4oIkgUK
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    smallcheck-1.1.3.1-CBUzkGh2qJwLP1YqH7XH7y
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             smallcheck-1.1.3.1-CBUzkGh2qJwLP1YqH7XH7y=6f7341215c90e69ab49f65de92e592b6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt=fb5a791b2b60259c4b58e72c51858b5d
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-GH1Y7L9GZFM6WskQ4EVtRL
key: tasty-smallcheck-0.8.1-GH1Y7L9GZFM6WskQ4EVtRL
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.SmallCheck
abi: a351b19f56ae56e5a29805d28777ae3d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-GH1Y7L9GZFM6WskQ4EVtRL
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    smallcheck-1.1.4-5aEylialiTw2NheYKH1WRj
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             smallcheck-1.1.4-5aEylialiTw2NheYKH1WRj=b1ad954b5986a2054b4bf3c3a4e29db1
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt=fb5a791b2b60259c4b58e72c51858b5d
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
